/*
 * version.h
 *
 * An OPAL GUI phone application.
 *
 * Open Phone Abstraction Library (OPAL)
 * Formally known as the Open H323 project.
 *
 * Copyright (c) 2007 Vox Lucida
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is Open Phone client.
 *
 * The Initial Developer of the Original Code is Robert Jongbloed
 *
 * Contributor(s): ______________________________________.
 *
 * $Revision$
 * $Author$
 * $Date$
 */

#ifndef _OpenPhone_VERSION_H
#define _OpenPhone_VERSION_H

#include "../../version.h"

#define	PRODUCT_NAME_TEXT	"Open Phone"
#define	EXE_NAME_TEXT	        "openphone"
#define	MANUFACTURER_TEXT	"Vox Lucida"
#define	COPYRIGHT_HOLDER	"Vox Lucida Pty. Ltd. (Australia)"


#endif  // _OpenPhone_VERSION_H


// End of File ///////////////////////////////////////////////////////////////
